pilas.asistente.VentanaAsistente

Package pilas :: Module asistente :: Class VentanaAsistente |
[hide private]
[frames] | no frames]

# Class VentanaAsistente

source code

                           object --+
                                    |
    asistente_base.Ui_AsistenteWindow --+
                                        |
                                       VentanaAsistente

Instance Methods | [hide private]
setupUi(self, main) | source code
_consultar_ultima_version_del_servidor(self) | source code
_cuando_termina_de_consultar_version(self, respuesta) | source code
_habilitar_inspector_web(self) | source code
_deshabilitar_barras_de_scroll(self) | source code
_cargar_pagina_principal(self) | source code
_obtener_html(self, file_path) | source code
cuando_pulsa_link(self, url) | source code
_ejecutar_ejemplo(self, categoria, nombre) Intenta ejecutar un programa de ejemplo en base a la categoria y nombre. | source code
_mostrar_codigo(self, categoria, nombre) | source code
_obtener_ruta_al_ejemplo(self, categoria, nombre) | source code
_cuando_termina_la_ejecucion_del_ejemplo(self, codigo, estado) Vuelve a permitir que se usen todos los botone de la interfaz. | source code
_cuando_selecciona_interprete(self) | source code
ejecutar_script(self, nombre_archivo_script) | source code
_ejecutar_comando(self, comando) Ejecuta un comando en segundo plano. | source code
_cuando_selecciona_abrir_manual(self) | source code
_consultar(self, parent, titulo, mensaje) Realizar una consulta usando un cuadro de dialogo. | source code
salir(self, *_) | source code
Inherited from `asistente_base.Ui_AsistenteWindow`: `retranslateUi` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### setupUi(self, main) | source code
Overrides: asistente_base.Ui_AsistenteWindow.setupUi

### _ejecutar_ejemplo(self, categoria, nombre) | source code
Intenta ejecutar un programa de ejemplo en base a la categoria y nombre. Internamente, esta funcion intenta buscar un archivo dentro de la ruta "../ejemplos/ejemplos/{categoria}/{nombre}.py".